pub struct RequestId(pub String);Expand description
A request ID that was extracted or generated for the current request.
This is stored in request extensions and can be retrieved by handlers or other middleware for logging and tracing.
Tuple Fields
0: StringImplementations