pub struct MultipartParser { /* private fields */ }Expand description
Multipart parser (boundary-based).
Implementations
Sourceimpl MultipartParser
impl MultipartParser
Sourcepub fn new(boundary: &str, config: MultipartConfig) -> Self
pub fn new(boundary: &str, config: MultipartConfig) -> Self
Create a new parser with the given boundary.
Sourcepub fn parse(&self, body: &[u8]) -> Result<Vec<Part>, MultipartError>
pub fn parse(&self, body: &[u8]) -> Result<Vec<Part>, MultipartError>
Parse all parts from the body.
Sourcepub fn parse_incremental(
&self,
buffer: &mut Vec<u8>,
state: &mut MultipartStreamState,
eof: bool,
) -> Result<Vec<Part>, MultipartError>
pub fn parse_incremental( &self, buffer: &mut Vec<u8>, state: &mut MultipartStreamState, eof: bool, ) -> Result<Vec<Part>, MultipartError>
Parse any newly-available parts from a streamed multipart buffer.
This method mutates buffer by draining bytes that were fully consumed.
It can be called repeatedly as new bytes arrive.
- Set
eof = falsewhile more chunks may still arrive. - Set
eof = trueon the final call to enforce that the stream ended on a valid multipart boundary.