pub struct AutoSpan { /* private fields */ }Expand description
Auto-ending span that logs duration on drop.
Unlike Span, this type automatically logs its duration
when it goes out of scope, making it ideal for RAII-style usage.
Implementations
Sourceimpl AutoSpan
impl AutoSpan
Sourcepub fn new(ctx: &RequestContext, name: impl Into<String>) -> Self
pub fn new(ctx: &RequestContext, name: impl Into<String>) -> Self
Creates a new auto-ending span using the default LogConfig.
The span end event is emitted at DEBUG level, so it will only be visible if DEBUG logging is enabled.
Sourcepub fn new_with_config(
ctx: &RequestContext,
config: LogConfig,
name: impl Into<String>,
) -> Self
pub fn new_with_config( ctx: &RequestContext, config: LogConfig, name: impl Into<String>, ) -> Self
Creates a new auto-ending span using an explicit LogConfig.
The span end event is emitted at DEBUG level, so it will only be visible if DEBUG logging is enabled.